@@ -1,5 +1,6 @@
+"""Contains all deployers implementations."""
 import pathlib
-import subprocess
+import subprocess  # nosec B404
 
 from py_mono_tools.config import consts, logger
 from py_mono_tools.goals.interface import Deployers, Language
@@ -15,6 +16,9 @@ class PoetryBuilder(Deployers):
         logger.info("running command: %s", commands)
 
         cwd = consts.EXECUTED_FROM
+        if self._pyproject_loc is None:
+            logger.error("pyproject.toml location not set")
+            raise ValueError("pyproject.toml location not set")
         cwd = cwd / pathlib.Path(self._pyproject_loc).parent
         cwd = cwd.resolve()
         logger.info("cwd: %s", cwd)
@@ -30,9 +34,11 @@ class PoetryBuilder(Deployers):
         return process.returncode, stderr_data.decode("utf-8") + stdout_data.decode("utf-8")
 
     def plan(self):
+        """Win run poetry build and poetry publish --dry-run."""
         return self.run(dry_run=True)
 
     def build(self):
+        """Will run poetry build."""
         commands = [
             "poetry",
             "build",
@@ -40,6 +46,7 @@ class PoetryBuilder(Deployers):
         return self._run_poetry(commands)
 
     def run(self, dry_run: bool = False):
+        """Will run poetry publish."""
         return_code, build_logs = self.build()
 
         logger.debug("build_return_code: %s build logs: %s", return_code, build_logs)
